@@ -9,7 +9,6 @@ from .state import *
 from .utils import *
 from .state import Constants as ingl_constants
 from rich import print
-import base64
 from solana.rpc.async_api import AsyncClient
 from .cli_state import CLI_VERSION
 uasyncclient = Uasyncclient(rpc_url.target_network)
@@ -22,7 +21,6 @@ def entry():
 
 @click.group(name="mint")
 async def mint():
-    log_level = int(log_level)
     pass
 
 async def mint_helper(keypair, log_level, class_enum):
@@ -31,7 +29,7 @@ async def mint_helper(keypair, log_level, class_enum):
     client_state = await client.is_connected()
     print("Client is connected" if client_state else "Client is Disconnected")
     payer_keypair = parse_keypair_input(f"./{keypair}")
-    mint_keypair = Keypair()
+    mint_keypair = KeypairInput(keypair = Keypair())
     print("Mint_Id: ", mint_keypair.public_key)
     t_dets = await mint_nft(payer_keypair, mint_keypair, class_enum, client, log_level)
     print(t_dets)
@@ -122,6 +120,38 @@ async def finalize_validator_proposal(keypair, log_level: int = 0):
     # client.close()
     print("Instruction has been deprecated. Use 'create_vote_account' instead.")
 
+@click.command(name="allocate_gem")
+@click.argument('mint_id')
+@click.option('--keypair', default = 'keypair.json')
+@click.option('--log_level', default = '2')
+async def allocate_gem(mint_id, keypair, log_level: int = 0):
+    log_level = int(log_level)
+    client = AsyncClient(rpc_url.target_network)
+    client_state = await client.is_connected()
+    print("Client is connected" if client_state else "Client is Disconnected")
+    payer_keypair = parse_keypair_input(f"./{keypair}")
+    mint_pubkey = parse_pubkey_input(mint_id)
+    t_dets = await allocate_gem(payer_keypair, mint_pubkey, client, log_level)
+    print(t_dets)
+    await client.close()
+
+@click.command(name="deallocate_gem")
+@click.argument('mint_id')
+@click.option('--keypair', default = 'keypair.json')
+@click.option('--log_level', default = '2')
+async def deallocate_gem(mint_id, keypair, log_level: int = 0):
+    log_level = int(log_level)
+    client = AsyncClient(rpc_url.target_network)
+    client_state = await client.is_connected()
+    print("Client is connected" if client_state else "Client is Disconnected")
+    payer_keypair = parse_keypair_input(f"./{keypair}")
+    mint_pubkey = parse_pubkey_input(mint_id)
+    t_dets = await deallocate_gem(payer_keypair, mint_pubkey, client, log_level)
+    print(t_dets)
+    await client.close()
+
+
+
 @click.command(name='register_validator')
 @click.option('--keypair', default = 'keypair.json')
 @click.argument('validator_keypair')
@@ -213,7 +243,7 @@ async def process_vote_account_rewards(keypair, vote_key, log_level: int = 0):
     await client.close()
 
 @click.command(name='create_vote_account')
-@click.argument('val_keypair')
+@click.option('--val_keypair', default = 'keypair.json')
 @click.option('--log_level', default = '2')
 async def process_create_vote_account(val_keypair, log_level: int = 0):
     log_level = int(log_level)
@@ -224,6 +254,9 @@ async def process_create_vote_account(val_keypair, log_level: int = 0):
     global_gem_pubkey, _global_gem_bump = PublicKey.find_program_address([bytes(ingl_constants.GLOBAL_GEM_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
     gem_info = await client.get_account_info(global_gem_pubkey)
     numeration = GlobalGems.parse(gem_info.value.data).proposal_numeration
+    if not GlobalGems.is_proposal_ongoing:
+        client.close
+        print("[warning]A Validator Selection Proposal is not ongoing!!![/warning]")
     t_dets = await create_vote_account(payer_keypair, numeration-1, client, log_level)
     print(t_dets)
     await client.close()
