@@ -69,7 +69,7 @@ async def ingl_init(payer_keypair: KeypairInput, client: AsyncClient, log_level:
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def mint_nft(payer_keypair: KeypairInput, mint_keypair: KeypairInput, mint_class: ClassEnum.enum, client: AsyncClient, log_level: int = 0) -> str:
     mint_authority_pubkey, _mint_authority_pubkey_bump = PublicKey.find_program_address([bytes(ingl_constants.INGL_MINT_AUTHORITY_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -83,7 +83,6 @@ async def mint_nft(payer_keypair: KeypairInput, mint_keypair: KeypairInput, mint
     mint_edition_pda, _mint_edition_bump = PublicKey.find_program_address([b"metadata", bytes(metaplex_program_id), bytes(mint_keypair.public_key), b"edition"], metaplex_program_id)
     collection_account_pda, _collection_account_bump = PublicKey.find_program_address([b"metadata", bytes(metaplex_program_id), bytes(collection_mint_pubkey)], metaplex_program_id)
     gem_account_pubkey, _gem_account_bump = PublicKey.find_program_address([bytes(ingl_constants.GEM_ACCOUNT_CONST, 'UTF-8'), bytes(mint_keypair.public_key)], ingl_constants.INGL_PROGRAM_ID)
-    # print("global gem: ", global_gem_pubkey)
     payer_account_meta = AccountMeta(payer_keypair.public_key, True, True)
     mint_account_meta = AccountMeta(mint_keypair.public_key, True, True)
     minting_pool_meta = AccountMeta(minting_pool_pubkey, False, True)
@@ -131,7 +130,7 @@ async def mint_nft(payer_keypair: KeypairInput, mint_keypair: KeypairInput, mint
         spl_program_meta,
         metadata_program_id,
     ]
-    # print(accounts)
+
     instruction_data = build_instruction(InstructionEnum.enum.MintNft(), log_level = log_level, mint_class = mint_class)
     transaction = Transaction()
     transaction.add(ComputeBudgetInstruction().set_compute_unit_limit(400_000, payer_keypair.public_key))
@@ -141,7 +140,7 @@ async def mint_nft(payer_keypair: KeypairInput, mint_keypair: KeypairInput, mint
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def allocate_sol(payer_keypair: KeypairInput, mint_pubkey: PubkeyInput, client: AsyncClient, log_level: int = 0) -> str:
     minting_pool_pubkey, _minting_pool_pubkey_bump = PublicKey.find_program_address([bytes(ingl_constants.INGL_MINTING_POOL_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -183,7 +182,7 @@ async def allocate_sol(payer_keypair: KeypairInput, mint_pubkey: PubkeyInput, cl
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def deallocate_sol(payer_keypair: KeypairInput, mint_pubkey: PubkeyInput, client: AsyncClient, log_level: int = 0) -> str:
     minting_pool_pubkey, _minting_pool_pubkey_bump = PublicKey.find_program_address([bytes(ingl_constants.INGL_MINTING_POOL_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -226,10 +225,10 @@ async def deallocate_sol(payer_keypair: KeypairInput, mint_pubkey: PubkeyInput,
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def register_validator_id(payer_keypair: KeypairInput, validator_pubkey: PubkeyInput, client: AsyncClient, log_level: int = 0) -> str:
-    mint_authority_pubkey, _mint_authority_pubkey_bump = PublicKey.find_program_address([bytes(ingl_constants.INGL_MINT_AUTHORITY_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
+    team_account_pubkey, _team_account_pubkey_bump = PublicKey.find_program_address([bytes(ingl_constants.INGL_TEAM_ACCOUNT, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
     global_gem_pubkey, _global_gem_bump = PublicKey.find_program_address([bytes(ingl_constants.GLOBAL_GEM_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
 
     dupkey, dup_bump = PublicKey.find_program_address([ingl_constants.DUPKEYBYTES, bytes(validator_pubkey.public_key)], ingl_constants.INGL_PROGRAM_ID);
@@ -238,7 +237,7 @@ async def register_validator_id(payer_keypair: KeypairInput, validator_pubkey: P
     payer_account_meta = AccountMeta(payer_keypair.public_key, True, True)
     global_gem_meta = AccountMeta(global_gem_pubkey, False, True)
     system_program_meta = AccountMeta(system_program.SYS_PROGRAM_ID, False, False)
-    mint_authority_meta = AccountMeta(mint_authority_pubkey, False, True)
+    mint_authority_meta = AccountMeta(team_account_pubkey, False, True)
     validator_meta = AccountMeta(validator_pubkey.public_key, False, False)
     dup_meta = AccountMeta(dupkey, False, True)
 
@@ -261,7 +260,7 @@ async def register_validator_id(payer_keypair: KeypairInput, validator_pubkey: P
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def create_validator_proposal(payer_keypair: KeypairInput, proposal_numeration: int, client: AsyncClient, log_level: int = 0) -> str:
     global_gem_pubkey, _global_gem_bump = PublicKey.find_program_address([bytes(ingl_constants.GLOBAL_GEM_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -288,7 +287,7 @@ async def create_validator_proposal(payer_keypair: KeypairInput, proposal_numera
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def vote_validator_proposal(payer_keypair: KeypairInput, proposal_numeration: int, mint_pubkeys: List[PublicKey], val_index:int, client: AsyncClient, log_level: int = 0) -> str:
     proposal_pubkey, _proposal_bump = PublicKey.find_program_address([bytes(ingl_constants.PROPOSAL_KEY, 'UTF-8'), proposal_numeration.to_bytes(4,"big")], ingl_constants.INGL_PROGRAM_ID)
@@ -320,7 +319,7 @@ async def vote_validator_proposal(payer_keypair: KeypairInput, proposal_numerati
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def finalize_proposal(payer_keypair: KeypairInput, client: AsyncClient, log_level: int = 0) -> str:
     global_gem_pubkey, _global_gem_bump = PublicKey.find_program_address([bytes(ingl_constants.GLOBAL_GEM_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -348,7 +347,7 @@ async def finalize_proposal(payer_keypair: KeypairInput, client: AsyncClient, lo
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def delegate_nft(payer_keypair: KeypairInput, mint_pubkey: PubkeyInput, expected_vote_pubkey: PubkeyInput, client: AsyncClient, log_level: int = 0) -> str:
     gem_account_pubkey, _gem_account_bump = PublicKey.find_program_address([bytes(ingl_constants.GEM_ACCOUNT_CONST, 'UTF-8'), bytes(mint_pubkey.public_key)], ingl_constants.INGL_PROGRAM_ID)
@@ -390,7 +389,7 @@ async def delegate_nft(payer_keypair: KeypairInput, mint_pubkey: PubkeyInput, ex
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def undelegate_nft(payer_keypair: KeypairInput, mint_pubkey: PubkeyInput, expected_vote_pubkey: PubkeyInput, client: AsyncClient, log_level: int = 0) -> str: #TODO: Need to include the 3 new accounts: Authorized_withdrawer, validator_info, and the system program in this instruction, without which instruction will consistently fail
     pd_pool_pubkey, _pd_pool_pubkey_bump = PublicKey.find_program_address([bytes(ingl_constants.PD_POOL_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -445,7 +444,7 @@ async def undelegate_nft(payer_keypair: KeypairInput, mint_pubkey: PubkeyInput,
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def create_vote_account(validator_keypair: KeypairInput, proposal_numeration: int, client: AsyncClient, log_level: int = 0) -> str:
     global_gem_pubkey, _global_gem_bump = PublicKey.find_program_address([bytes(ingl_constants.GLOBAL_GEM_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -505,7 +504,7 @@ async def create_vote_account(validator_keypair: KeypairInput, proposal_numerati
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def close_proposal(payer_keypair: KeypairInput, proposal_numeration: int, client: AsyncClient, log_level: int = 0) -> str:
     global_gem_pubkey, _global_gem_bump = PublicKey.find_program_address([bytes(ingl_constants.GLOBAL_GEM_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -538,7 +537,7 @@ async def close_proposal(payer_keypair: KeypairInput, proposal_numeration: int,
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def init_rebalance(payer_keypair: KeypairInput, vote_account_pubkey: PubkeyInput, client: AsyncClient, log_level: int = 0) -> str:
     global_gem_pubkey, _global_gem_bump = PublicKey.find_program_address([bytes(ingl_constants.GLOBAL_GEM_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -595,7 +594,7 @@ async def init_rebalance(payer_keypair: KeypairInput, vote_account_pubkey: Pubke
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def finalize_rebalance(payer_keypair: KeypairInput, vote_account_pubkey: PubkeyInput, client: AsyncClient, log_level: int = 0) -> str:
     expected_vote_pubkey = vote_account_pubkey.public_key
@@ -646,7 +645,7 @@ async def finalize_rebalance(payer_keypair: KeypairInput, vote_account_pubkey: P
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def process_rewards(payer_keypair: KeypairInput, vote_account_id: PubkeyInput, client: AsyncClient, log_level: int = 0) -> str:
     ingl_team_account_pubkey, _ita_bump = PublicKey.find_program_address([bytes(ingl_constants.INGL_TEAM_ACCOUNT, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -692,7 +691,7 @@ async def process_rewards(payer_keypair: KeypairInput, vote_account_id: PubkeyIn
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def nft_withdraw(payer_keypair: KeypairInput, mints: List[PublicKey], vote_account_id: PubkeyInput, client: AsyncClient, log_level: int = 0) -> str:
     expected_vote_data_pubkey, _expected_vote_data_bump = PublicKey.find_program_address([bytes(ingl_constants.VOTE_DATA_ACCOUNT_KEY, 'UTF-8'), bytes(vote_account_id)], ingl_constants.INGL_PROGRAM_ID)
@@ -736,7 +735,7 @@ async def nft_withdraw(payer_keypair: KeypairInput, mints: List[PublicKey], vote
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def inject_testing_data(payer_keypair: KeypairInput, mints: List[PublicKey], vote_account_id: PubkeyInput, client: AsyncClient, log_level: int = 0) -> str:
     expected_vote_data_pubkey, _expected_vote_data_bump = PublicKey.find_program_address([bytes(ingl_constants.VOTE_DATA_ACCOUNT_KEY, 'UTF-8'), bytes(vote_account_id.public_key)], ingl_constants.INGL_PROGRAM_ID)
@@ -774,7 +773,7 @@ async def inject_testing_data(payer_keypair: KeypairInput, mints: List[PublicKey
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def create_program_upgrade_proposal(payer_keypair: KeypairInput, buffer_address: PubkeyInput, proposal_numeration: int, code_link: String,  client: AsyncClient, log_level: int = 0) -> str:
     ingl_team_account_pubkey, _ita_bump = PublicKey.find_program_address([bytes(ingl_constants.INGL_TEAM_ACCOUNT, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -810,7 +809,7 @@ async def create_program_upgrade_proposal(payer_keypair: KeypairInput, buffer_ad
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def vote_program_upgrade_proposal(payer_keypair: KeypairInput, vote: Bool, upgrade_proposal_pubkey: Optional[PubkeyInput], upgrade_numeration: Optional[int], vote_account_proposal_pubkey: Optional[PubkeyInput],  vote_account_numeration: Optional[int], client: AsyncClient, log_level: int = 0) -> str:
     global_gem_pubkey, _global_gem_bump = PublicKey.find_program_address([bytes(ingl_constants.GLOBAL_GEM_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -847,7 +846,7 @@ async def vote_program_upgrade_proposal(payer_keypair: KeypairInput, vote: Bool,
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
+        return(f"[warning]Error: {e}[/warning]")
 
 async def finalize_program_upgrade_proposal(payer_keypair: KeypairInput, upgrade_proposal_pubkey: Optional[PubkeyInput], upgrade_numeration: Optional[int], client: AsyncClient, log_level: int = 0) -> str:
     ingl_team_account_pubkey, _ita_bump = PublicKey.find_program_address([bytes(ingl_constants.INGL_TEAM_ACCOUNT, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
@@ -902,4 +901,4 @@ async def finalize_program_upgrade_proposal(payer_keypair: KeypairInput, upgrade
         await client.confirm_transaction(tx_sig = t_dets.value, commitment= "finalized", sleep_seconds = 0.4, last_valid_block_height = None)
         return f"Transaction Id: [link=https://explorer.solana.com/tx/{str(t_dets.value)+rpc_url.get_explorer_suffix()}]{str(t_dets.value)}[/link]"
     except Exception as e:
-        return(f"Error: {e}")
\ No newline at end of file
+        return(f"[warning]Error: {e}[/warning]")
\ No newline at end of file
