@@ -153,6 +153,7 @@ class rpc_url:
 
 class KeypairInput:
     def __init__(self, keypair: Optional[Keypair] = None, ledger_address: Optional[int] = None, pubkey: Optional[PublicKey] = None):
+        assert keypair or ledger_address, "KeypairInput must have at least one of keypair or ledger_address"
         self.keypair = keypair
         self.ledger_address = ledger_address
         self.public_key = pubkey if pubkey else keypair.public_key if keypair else None
@@ -167,9 +168,10 @@ def parse_keypair_input(str_input: String) -> KeypairInput:
         return KeypairInput(keypair=t_keypair, pubkey=t_keypair.public_key)
 class PubkeyInput:
     def __init__(self, keypair: Optional[Keypair] = None, pubkey: Optional[PublicKey] = None, ledger_address: Optional[int] = None):
-        self.public_key = pubkey
-        self.ledger_address = ledger_address
+        assert keypair or pubkey or ledger_address, "PubkeyInput must have at least one of keypair, pubkey or ledger_address"
         self.keypair = keypair
+        self.public_key = keypair.public_key if keypair else pubkey
+        self.ledger_address = ledger_address
 
 def parse_pubkey_input(str_input: String) -> PubkeyInput:
     if str_input.startswith("Ledger://"):
